==> frostwire_5.3.9.orig.tar.gz: frostwire-5.3.9/core/com/limegroup/gnutella/util/MacOSXUtils.java <==
package com.limegroup.gnutella.util;

import org.limewire.service.ErrorService;
import org.limewire.util.CommonUtils;

/**
 * A collection of utility methods for OSX.
 * These methods should only be called if run from OSX,
 * otherwise ClassNotFoundErrors may occur.
 *
 * To determine if the Cocoa Foundation classes are present,
 * use the method CommonUtils.isCocoaFoundationAvailable().
 */
public class MacOSXUtils {
    
    static {
//        if (OSUtils.isMacOSX105()) {
//            try {
//                System.loadLibrary("MacOSXUtilsTiger");
//            }
//            catch (UnsatisfiedLinkError err) {
//                ErrorService.error(err);
//            }
//        } else {
        	try {
        		System.loadLibrary("MacOSXUtilsLeopard");
        	} catch (UnsatisfiedLinkError err) {
            	ErrorService.error(err);
            }
//        }
    }
    
    private MacOSXUtils() {}
    
    /**
     * The name of the app that launches.
     */
    private static final String APP_NAME = "FrostWire.app";

    /**
     * Modifies the loginwindow.plist file to either include or exclude
     * starting up FrostWire.
     */
    public static void setLoginStatus(boolean allow) {
        SetLoginStatusNative(allow);
    }
    
    /**
     * Gets the full user's name.
     */
    public static String getUserName() {
        return GetCurrentFullUserName();
    }
    
    /**
     * Retrieves the app directory & name.
     * If the user is not running from the bundled app as we named it,
     * defaults to /Applications/FrostWire/ as the directory of the app.
     */
    public static String getAppDir() {
        String appDir = "/Applications/FrostWire/";
        String path = CommonUtils.getCurrentDirectory().getPath();
        int app = path.indexOf("FrostWire.app");
        if(app != -1)
            appDir = path.substring(0, app);
        return appDir + APP_NAME;
    }
    
    /**
     * Gets the full user's name.
     */
    private static final native String GetCurrentFullUserName();
    
    /**
     * [Un]registers FrostWire from the startup items list.
     */
    private static final native void SetLoginStatusNative(boolean allow);
}

==> frostwire_5.7.0.orig.tar.gz: frostwire-5.7.0/core/com/limegroup/gnutella/util/MacOSXUtils.java <==
package com.limegroup.gnutella.util;

import org.limewire.util.CommonUtils;

/**
 * A collection of utility methods for OSX.
 * These methods should only be called if run from OSX,
 * otherwise ClassNotFoundErrors may occur.
 *
 * To determine if the Cocoa Foundation classes are present,
 * use the method CommonUtils.isCocoaFoundationAvailable().
 */
public class MacOSXUtils {
    
	private static boolean initialized = false;
	
    static {
        	try {
        		System.loadLibrary("MacOSXUtilsLeopard");
        		initialized = true;
        	} catch (Throwable err) {
            }
    }
    
    private MacOSXUtils() {}
    
    /**
     * The name of the app that launches.
     */
    private static final String APP_NAME = "FrostWire.app";

    /**
     * Modifies mac OSX environment to run this application on startup
     */
    public static void setLoginStatus(boolean allow) {
    	
    	if (initialized) {
	    	String rawDir = CommonUtils.getExecutableDirectory();
	    	String path = rawDir.substring(0, rawDir.indexOf(APP_NAME) + APP_NAME.length());
	    	
	        SetLoginStatusNative(allow, path );
    	}
    }
    
    /**
     * Gets the full user's name.
     */
    public static String getUserName() {
    	if (initialized) {
    		return GetCurrentFullUserName();
    	}
    	else {
    		return "";
    	}
    }
    
    /**
     * Gets the full user's name.
     */
    private static final native String GetCurrentFullUserName();
    
    /**
     * [Un]registers FrostWire from the startup items list.
     */
    private static final native void SetLoginStatusNative(boolean allow, String appPath);
}
